@@ -192,8 +192,12 @@ class VariableClUpdateRepPath(ReadonlyVariable):
     Пути до репозиториев
     """
     type = "list"
-    mapPath = {'portage': 'usr/portage',
-               'gentoo': 'usr/portage'}
+    if os.path.isdir('/var/db/repos/gentoo'):
+        mapPath = {'portage': 'var/db/repos/gentoo',
+                   'gentoo': 'var/db/repos/gentoo'}
+    else:
+        mapPath = {'portage': 'usr/portage',
+                   'gentoo': 'usr/portage'}
 
     def get(self):
         repPath = self.Get('cl_update_repos_storage')
